@@ -22,6 +22,27 @@ function openstack_bootstrap_preprocess_page(&$variables) {
     unset($variables['navbar_classes_array'][$key]);
     $variables['navbar_classes_array'][] = 'navbar-os';
   }
+  drupal_add_css('//netdna.bootstrapcdn.com/font-awesome/4.4.0/css/font-awesome.css', array('type' => 'external'));
+}
+
+/**
+ * Implements hook_preprocess_html().
+ *
+ * Add bleed-margins class to
+ *  - front page
+ *  - ambassador program
+ *
+ * and add no-bleed-margins to each other page.
+ *
+ * @see html.tpl.php
+ */
+function openstack_bootstrap_preprocess_html(&$variables) {
+  $path_alias = drupal_get_path_alias();
+  if (($variables['is_front']) || ($path_alias == 'ambassador-program')) {
+    $variables['classes_array'][] = 'bleed-margins';
+  } else {
+    $variables['classes_array'][] = 'no-bleed-margins';
+  }
 }
 
 /**
@@ -236,6 +257,18 @@ function openstack_bootstrap_preprocess_views_view(&$variables) {
 function openstack_bootstrap_preprocess_user_profile(&$variables) {
   global $user;
   $account = $variables['elements']['#account'];
+  if ($variables['elements']['#view_mode'] == 'profile_teaser') {
+    $node_wrapper = entity_metadata_wrapper('user', $account);
+    $region_value = $node_wrapper->field_ambassador_region->value();
+    if (isset($region_value)) {
+      module_load_include('inc', 'field_group_location', 'field_group_lookup');
+      $continents = _continent_get_predefined_list();
+      $variables['user_profile']['name'][0] = array(
+        '#markup' => '<h3><a href="">'.$account->name.
+          ' <span class="ambassador-region">// '.$continents[$region_value].'</span></a></h3>',
+      );
+    }
+  }
   if (in_array('ambassador', $account->roles)) {
     $variables['user_profile']['role_ambassador'] = array(
       '#prefix' => '<span class="label label-info">',
